### Versions

|Date|Tag|What have been done|What going to change|
|-|-|-|-|
|2019-02-17|__v0.1__|Init the project||
|2019-03-10|__v0.2__|Support other domains||
|2019-05-20|__v0.3__|Support the new version of API||
|2020-04-10|__v0.4__|Add a function to download all pages||
|2020-04-13|__v0.5__|Add a function convert json to tsv||
|2020-05-14|__v0.6__|Fixed a bug in auth with different base url||
|2020-05-20|__v0.7__|Update page size for download all||
|2020-05-22|__v0.8__|rm line breaks in tsv export||
|2020-05-28|__v0.9__|updated column value to data||
|2020-10-07|__v0.10__|add function to check token||
|2021-06-09|__v0.11__|supoort MFA in auth||
|2022-01-18|__v0.12__|support python3||
|2022-02-22|__v1.0__|support pip package||
|2022-02-22|__v1.01__|updated images at README.md||
|2022-02-22|__v1.02__|updated readme links||
|2022-02-22|__v1.03__|support more objects||
|2022-02-22|__v1.04__|support more models||
|2022-02-22|__v1.05__|fixed a bug to load all pages||
|2022-02-23|__v1.06__|fixed bug to load user info||
|2022-02-23|__v1.07__|support query in sdk methods||
|2022-02-28|__v1.08__|support file uploading||
|2022-04-20|__v1.09__|support folder watch||
|2023-02-05|__v1.10.0__|support labii 8.0.0||
|2023-08-03|__v1.11.0__|updated the file upload function||
|2023-08-03|__v1.11.1__|updated to allow use additional api object||
|2023-08-03|__v1.11.2__|fixed a status code bug in delete||
|2023-08-10|__v1.11.3__|support notifications||
|2023-08-13|__v1.12.0__|support api key authentification||
|2023-08-13|__v1.12.1__|added switch organization||
|2023-08-18|__v1.12.2__|support error message from response||
|2023-09-01|__v1.13.0__|added get_columns function||
|2023-09-01|__v1.13.1__|fixed bug for applications||
|2023-09-22|__v1.13.2__|update delete message||
